# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/materialization_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaskada.kaskada.v1alpha import common_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_common__pb2
from kaskada.kaskada.v1alpha import destinations_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_destinations__pb2
from kaskada.kaskada.v1alpha import schema_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_schema__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5kaskada/kaskada/v1alpha/materialization_service.proto\x12\x17kaskada.kaskada.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$kaskada/kaskada/v1alpha/common.proto\x1a*kaskada/kaskada/v1alpha/destinations.proto\x1a$kaskada/kaskada/v1alpha/schema.proto\x1a\x17validate/validate.proto\"P\n\x08WithView\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12\'\n\nexpression\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nexpression\"D\n\tWithViews\x12\x37\n\x05views\x18\x01 \x03(\x0b\x32!.kaskada.kaskada.v1alpha.WithViewR\x05views\"\xea\x05\n\x0fMaterialization\x12\x32\n\x12materialization_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x11materializationId\x12:\n\x14materialization_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\x12@\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\x14\n\x05query\x18\x04 \x01(\tR\x05query\x12@\n\nwith_views\x18\x05 \x03(\x0b\x32!.kaskada.kaskada.v1alpha.WithViewR\twithViews\x12V\n\x0b\x64\x65stination\x18\x06 \x01(\x0b\x32\x34.kaskada.kaskada.v1alpha.Materialization.DestinationR\x0b\x64\x65stination\x12<\n\x06schema\x18\x07 \x01(\x0b\x32\x1f.kaskada.kaskada.v1alpha.SchemaB\x03\xe0\x41\x03R\x06schema\x12;\n\x05slice\x18\x08 \x01(\x0b\x32%.kaskada.kaskada.v1alpha.SliceRequestR\x05slice\x12\x42\n\x08\x61nalysis\x18\t \x01(\x0b\x32!.kaskada.kaskada.v1alpha.AnalysisB\x03\xe0\x41\x03R\x08\x61nalysis\x1a\xb5\x01\n\x0b\x44\x65stination\x12\x41\n\x05redis\x18\x01 \x01(\x0b\x32).kaskada.kaskada.v1alpha.RedisDestinationH\x00R\x05redis\x12T\n\x0cobject_store\x18\x02 \x01(\x0b\x32/.kaskada.kaskada.v1alpha.ObjectStoreDestinationH\x00R\x0bobjectStoreB\r\n\x0b\x64\x65stination\"}\n\x1bListMaterializationsRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xee\x01\n\x1cListMaterializationsResponse\x12T\n\x10materializations\x18\x01 \x03(\x0b\x32(.kaskada.kaskada.v1alpha.MaterializationR\x10materializations\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12P\n\x0frequest_details\x18\x03 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails\"W\n\x19GetMaterializationRequest\x12:\n\x14materialization_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\"\xc2\x01\n\x1aGetMaterializationResponse\x12R\n\x0fmaterialization\x18\x01 \x01(\x0b\x32(.kaskada.kaskada.v1alpha.MaterializationR\x0fmaterialization\x12P\n\x0frequest_details\x18\x02 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails\"\x8b\x01\n\x1c\x43reateMaterializationRequest\x12R\n\x0fmaterialization\x18\x01 \x01(\x0b\x32(.kaskada.kaskada.v1alpha.MaterializationR\x0fmaterialization\x12\x17\n\x07\x64ry_run\x18\x02 \x01(\x08R\x06\x64ryRun\"\x84\x02\n\x1d\x43reateMaterializationResponse\x12R\n\x0fmaterialization\x18\x01 \x01(\x0b\x32(.kaskada.kaskada.v1alpha.MaterializationR\x0fmaterialization\x12P\n\x0frequest_details\x18\x02 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails\x12=\n\x08\x61nalysis\x18\x03 \x01(\x0b\x32!.kaskada.kaskada.v1alpha.AnalysisR\x08\x61nalysis\"Z\n\x1c\x44\x65leteMaterializationRequest\x12:\n\x14materialization_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\"q\n\x1d\x44\x65leteMaterializationResponse\x12P\n\x0frequest_details\x18\x01 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails2\xff\x05\n\x16MaterializationService\x12\xa6\x01\n\x14ListMaterializations\x12\x34.kaskada.kaskada.v1alpha.ListMaterializationsRequest\x1a\x35.kaskada.kaskada.v1alpha.ListMaterializationsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1alpha/materializations\x12\xb9\x01\n\x12GetMaterialization\x12\x32.kaskada.kaskada.v1alpha.GetMaterializationRequest\x1a\x33.kaskada.kaskada.v1alpha.GetMaterializationResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/v1alpha/materializations/{materialization_name=*}\x12\xba\x01\n\x15\x43reateMaterialization\x12\x35.kaskada.kaskada.v1alpha.CreateMaterializationRequest\x1a\x36.kaskada.kaskada.v1alpha.CreateMaterializationResponse\"2\x82\xd3\xe4\x93\x02,:\x0fmaterialization\"\x19/v1alpha/materializations\x12\xc2\x01\n\x15\x44\x65leteMaterialization\x12\x35.kaskada.kaskada.v1alpha.DeleteMaterializationRequest\x1a\x36.kaskada.kaskada.v1alpha.DeleteMaterializationResponse\":\x82\xd3\xe4\x93\x02\x34*2/v1alpha/materializations/{materialization_name=*}B\x8b\x02\n\x1b\x63om.kaskada.kaskada.v1alphaB\x1bMaterializationServiceProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')



_WITHVIEW = DESCRIPTOR.message_types_by_name['WithView']
_WITHVIEWS = DESCRIPTOR.message_types_by_name['WithViews']
_MATERIALIZATION = DESCRIPTOR.message_types_by_name['Materialization']
_MATERIALIZATION_DESTINATION = _MATERIALIZATION.nested_types_by_name['Destination']
_LISTMATERIALIZATIONSREQUEST = DESCRIPTOR.message_types_by_name['ListMaterializationsRequest']
_LISTMATERIALIZATIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListMaterializationsResponse']
_GETMATERIALIZATIONREQUEST = DESCRIPTOR.message_types_by_name['GetMaterializationRequest']
_GETMATERIALIZATIONRESPONSE = DESCRIPTOR.message_types_by_name['GetMaterializationResponse']
_CREATEMATERIALIZATIONREQUEST = DESCRIPTOR.message_types_by_name['CreateMaterializationRequest']
_CREATEMATERIALIZATIONRESPONSE = DESCRIPTOR.message_types_by_name['CreateMaterializationResponse']
_DELETEMATERIALIZATIONREQUEST = DESCRIPTOR.message_types_by_name['DeleteMaterializationRequest']
_DELETEMATERIALIZATIONRESPONSE = DESCRIPTOR.message_types_by_name['DeleteMaterializationResponse']
WithView = _reflection.GeneratedProtocolMessageType('WithView', (_message.Message,), {
  'DESCRIPTOR' : _WITHVIEW,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.WithView)
  })
_sym_db.RegisterMessage(WithView)

WithViews = _reflection.GeneratedProtocolMessageType('WithViews', (_message.Message,), {
  'DESCRIPTOR' : _WITHVIEWS,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.WithViews)
  })
_sym_db.RegisterMessage(WithViews)

Materialization = _reflection.GeneratedProtocolMessageType('Materialization', (_message.Message,), {

  'Destination' : _reflection.GeneratedProtocolMessageType('Destination', (_message.Message,), {
    'DESCRIPTOR' : _MATERIALIZATION_DESTINATION,
    '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Materialization.Destination)
    })
  ,
  'DESCRIPTOR' : _MATERIALIZATION,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Materialization)
  })
_sym_db.RegisterMessage(Materialization)
_sym_db.RegisterMessage(Materialization.Destination)

ListMaterializationsRequest = _reflection.GeneratedProtocolMessageType('ListMaterializationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMATERIALIZATIONSREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ListMaterializationsRequest)
  })
_sym_db.RegisterMessage(ListMaterializationsRequest)

ListMaterializationsResponse = _reflection.GeneratedProtocolMessageType('ListMaterializationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMATERIALIZATIONSRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ListMaterializationsResponse)
  })
_sym_db.RegisterMessage(ListMaterializationsResponse)

GetMaterializationRequest = _reflection.GeneratedProtocolMessageType('GetMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetMaterializationRequest)
  })
_sym_db.RegisterMessage(GetMaterializationRequest)

GetMaterializationResponse = _reflection.GeneratedProtocolMessageType('GetMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetMaterializationResponse)
  })
_sym_db.RegisterMessage(GetMaterializationResponse)

CreateMaterializationRequest = _reflection.GeneratedProtocolMessageType('CreateMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateMaterializationRequest)
  })
_sym_db.RegisterMessage(CreateMaterializationRequest)

CreateMaterializationResponse = _reflection.GeneratedProtocolMessageType('CreateMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.CreateMaterializationResponse)
  })
_sym_db.RegisterMessage(CreateMaterializationResponse)

DeleteMaterializationRequest = _reflection.GeneratedProtocolMessageType('DeleteMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.DeleteMaterializationRequest)
  })
_sym_db.RegisterMessage(DeleteMaterializationRequest)

DeleteMaterializationResponse = _reflection.GeneratedProtocolMessageType('DeleteMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.materialization_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.DeleteMaterializationResponse)
  })
_sym_db.RegisterMessage(DeleteMaterializationResponse)

_MATERIALIZATIONSERVICE = DESCRIPTOR.services_by_name['MaterializationService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\033MaterializationServiceProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _WITHVIEW.fields_by_name['name']._options = None
  _WITHVIEW.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _WITHVIEW.fields_by_name['expression']._options = None
  _WITHVIEW.fields_by_name['expression']._serialized_options = b'\372B\004r\002\020\001'
  _MATERIALIZATION.fields_by_name['materialization_id']._options = None
  _MATERIALIZATION.fields_by_name['materialization_id']._serialized_options = b'\340A\003'
  _MATERIALIZATION.fields_by_name['materialization_name']._options = None
  _MATERIALIZATION.fields_by_name['materialization_name']._serialized_options = b'\372B\004r\002\020\001'
  _MATERIALIZATION.fields_by_name['create_time']._options = None
  _MATERIALIZATION.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _MATERIALIZATION.fields_by_name['schema']._options = None
  _MATERIALIZATION.fields_by_name['schema']._serialized_options = b'\340A\003'
  _MATERIALIZATION.fields_by_name['analysis']._options = None
  _MATERIALIZATION.fields_by_name['analysis']._serialized_options = b'\340A\003'
  _LISTMATERIALIZATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTMATERIALIZATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372B\007\032\005\030\350\007(\000'
  _GETMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._options = None
  _GETMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._serialized_options = b'\372B\004r\002\020\001'
  _DELETEMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._options = None
  _DELETEMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._serialized_options = b'\372B\004r\002\020\001'
  _MATERIALIZATIONSERVICE.methods_by_name['ListMaterializations']._options = None
  _MATERIALIZATIONSERVICE.methods_by_name['ListMaterializations']._serialized_options = b'\202\323\344\223\002\033\022\031/v1alpha/materializations'
  _MATERIALIZATIONSERVICE.methods_by_name['GetMaterialization']._options = None
  _MATERIALIZATIONSERVICE.methods_by_name['GetMaterialization']._serialized_options = b'\202\323\344\223\0024\0222/v1alpha/materializations/{materialization_name=*}'
  _MATERIALIZATIONSERVICE.methods_by_name['CreateMaterialization']._options = None
  _MATERIALIZATIONSERVICE.methods_by_name['CreateMaterialization']._serialized_options = b'\202\323\344\223\002,:\017materialization\"\031/v1alpha/materializations'
  _MATERIALIZATIONSERVICE.methods_by_name['DeleteMaterialization']._options = None
  _MATERIALIZATIONSERVICE.methods_by_name['DeleteMaterialization']._serialized_options = b'\202\323\344\223\0024*2/v1alpha/materializations/{materialization_name=*}'
  _WITHVIEW._serialized_start=323
  _WITHVIEW._serialized_end=403
  _WITHVIEWS._serialized_start=405
  _WITHVIEWS._serialized_end=473
  _MATERIALIZATION._serialized_start=476
  _MATERIALIZATION._serialized_end=1222
  _MATERIALIZATION_DESTINATION._serialized_start=1041
  _MATERIALIZATION_DESTINATION._serialized_end=1222
  _LISTMATERIALIZATIONSREQUEST._serialized_start=1224
  _LISTMATERIALIZATIONSREQUEST._serialized_end=1349
  _LISTMATERIALIZATIONSRESPONSE._serialized_start=1352
  _LISTMATERIALIZATIONSRESPONSE._serialized_end=1590
  _GETMATERIALIZATIONREQUEST._serialized_start=1592
  _GETMATERIALIZATIONREQUEST._serialized_end=1679
  _GETMATERIALIZATIONRESPONSE._serialized_start=1682
  _GETMATERIALIZATIONRESPONSE._serialized_end=1876
  _CREATEMATERIALIZATIONREQUEST._serialized_start=1879
  _CREATEMATERIALIZATIONREQUEST._serialized_end=2018
  _CREATEMATERIALIZATIONRESPONSE._serialized_start=2021
  _CREATEMATERIALIZATIONRESPONSE._serialized_end=2281
  _DELETEMATERIALIZATIONREQUEST._serialized_start=2283
  _DELETEMATERIALIZATIONREQUEST._serialized_end=2373
  _DELETEMATERIALIZATIONRESPONSE._serialized_start=2375
  _DELETEMATERIALIZATIONRESPONSE._serialized_end=2488
  _MATERIALIZATIONSERVICE._serialized_start=2491
  _MATERIALIZATIONSERVICE._serialized_end=3258
# @@protoc_insertion_point(module_scope)



import platform
import socket
import subprocess
from contextlib import closing


def run_subprocess(cmd: str):
    return subprocess.Popen(cmd, shell=True)


def check_socket(endpoint: str) -> bool:
    parse = endpoint.split(":")
    if len(parse) != 2:
        raise ValueError("endpoint is not formatted correctly. host:port")

    host = parse[0]
    port = int(parse[1])
    with closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as sock:
        return sock.connect_ex((host, port)) == 0


def get_platform_details() -> str:
    """Gets the platform string mapping

    Returns:
        str: The current system platform mapping
    """
    platform_str = f"{platform.system().lower()}-{platform.machine()}"
    PLATFORMS = {
        "linux-x86_64": "linux-amd64",
        "darwin-x86_64": "darwin-amd64",
        "darwin-arm64": "darwin-arm64",
        "windows-amd64": "windows-amd64",
    }

    try:
        return PLATFORMS[platform_str]
    except KeyError:
        raise RuntimeError(f"unable to find binary matching: {platform_str}")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from kaskada.kaskada.v1alpha import fenl_diagnostics_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_fenl__diagnostics__pb2
from kaskada.kaskada.v1alpha import schema_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_schema__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$kaskada/kaskada/v1alpha/common.proto\x12\x17kaskada.kaskada.v1alpha\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a.kaskada/kaskada/v1alpha/fenl_diagnostics.proto\x1a$kaskada/kaskada/v1alpha/schema.proto\"q\n\x08\x46ilePath\x12#\n\x0cparquet_path\x18\x01 \x01(\tH\x00R\x0bparquetPath\x12\x1b\n\x08\x63sv_path\x18\x02 \x01(\tH\x00R\x07\x63svPath\x12\x1b\n\x08\x63sv_data\x18\x03 \x01(\tH\x00R\x07\x63svDataB\x06\n\x04path\"]\n\tFileInput\x12>\n\tfile_type\x18\x01 \x01(\x0e\x32!.kaskada.kaskada.v1alpha.FileTypeR\x08\x66ileType\x12\x10\n\x03uri\x18\x02 \x01(\tR\x03uri\"c\n\x0b\x46ileResults\x12>\n\tfile_type\x18\x01 \x01(\x0e\x32!.kaskada.kaskada.v1alpha.FileTypeR\x08\x66ileType\x12\x14\n\x05paths\x18\x02 \x03(\tR\x05paths\"I\n\x07\x41sFiles\x12>\n\tfile_type\x18\x01 \x01(\x0e\x32!.kaskada.kaskada.v1alpha.FileTypeR\x08\x66ileType\"\xf5\x01\n\x0bTableConfig\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04uuid\x18\x06 \x01(\tR\x04uuid\x12(\n\x10time_column_name\x18\x02 \x01(\tR\x0etimeColumnName\x12L\n\x13subsort_column_name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x11subsortColumnName\x12*\n\x11group_column_name\x18\x04 \x01(\tR\x0fgroupColumnName\x12\x1a\n\x08grouping\x18\x05 \x01(\tR\x08grouping\"g\n\rTableMetadata\x12\x37\n\x06schema\x18\x01 \x01(\x0b\x32\x1f.kaskada.kaskada.v1alpha.SchemaR\x06schema\x12\x1d\n\nfile_count\x18\x02 \x01(\x03R\tfileCount\"\xe6\x01\n\x0cPreparedFile\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12@\n\x0emin_event_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0cminEventTime\x12@\n\x0emax_event_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0cmaxEventTime\x12\x19\n\x08num_rows\x18\x04 \x01(\x03R\x07numRows\x12#\n\rmetadata_path\x18\x05 \x01(\tR\x0cmetadataPath\"\x88\x01\n\x14PreparedFileMetadata\x12\"\n\rraw_file_path\x18\x01 \x01(\tR\x0brawFilePath\x12L\n\x0eprepared_files\x18\x02 \x03(\x0b\x32%.kaskada.kaskada.v1alpha.PreparedFileR\rpreparedFiles\"\xb5\x02\n\tSlicePlan\x12\x1d\n\ntable_name\x18\x01 \x01(\tR\ttableName\x12K\n\x07percent\x18\x02 \x01(\x0b\x32/.kaskada.kaskada.v1alpha.SlicePlan.PercentSliceH\x00R\x07percent\x12U\n\x0b\x65ntity_keys\x18\x03 \x01(\x0b\x32\x32.kaskada.kaskada.v1alpha.SlicePlan.EntityKeysSliceH\x00R\nentityKeys\x1a(\n\x0cPercentSlice\x12\x18\n\x07percent\x18\x01 \x01(\x01R\x07percent\x1a\x32\n\x0f\x45ntityKeysSlice\x12\x1f\n\x0b\x65ntity_keys\x18\x01 \x03(\tR\nentityKeysB\x07\n\x05slice\",\n\x04Uuid\x12\x12\n\x04high\x18\x01 \x01(\x04R\x04high\x12\x10\n\x03low\x18\x02 \x01(\x04R\x03low\"\x9f\x02\n\x0cSliceRequest\x12N\n\x07percent\x18\x01 \x01(\x0b\x32\x32.kaskada.kaskada.v1alpha.SliceRequest.PercentSliceH\x00R\x07percent\x12X\n\x0b\x65ntity_keys\x18\x02 \x01(\x0b\x32\x35.kaskada.kaskada.v1alpha.SliceRequest.EntityKeysSliceH\x00R\nentityKeys\x1a(\n\x0cPercentSlice\x12\x18\n\x07percent\x18\x01 \x01(\x01R\x07percent\x1a\x32\n\x0f\x45ntityKeysSlice\x12\x1f\n\x0b\x65ntity_keys\x18\x02 \x03(\tR\nentityKeysB\x07\n\x05slice\"\xc4\x01\n\x08\x41nalysis\x12#\n\rmissing_names\x18\x01 \x03(\tR\x0cmissingNames\x12S\n\x10\x66\x65nl_diagnostics\x18\x02 \x01(\x0b\x32(.kaskada.kaskada.v1alpha.FenlDiagnosticsR\x0f\x66\x65nlDiagnostics\x12\x1f\n\x0b\x63\x61n_execute\x18\x03 \x01(\x08R\ncanExecute\x12\x1d\n\nfree_names\x18\x04 \x03(\tR\tfreeNames\"/\n\x0eRequestDetails\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId*O\n\x08\x46ileType\x12\x19\n\x15\x46ILE_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11\x46ILE_TYPE_PARQUET\x10\x01\x12\x11\n\rFILE_TYPE_CSV\x10\x02*\x9b\x01\n\x11PerEntityBehavior\x12#\n\x1fPER_ENTITY_BEHAVIOR_UNSPECIFIED\x10\x00\x12\x1b\n\x17PER_ENTITY_BEHAVIOR_ALL\x10\x01\x12\x1d\n\x19PER_ENTITY_BEHAVIOR_FINAL\x10\x02\x12%\n!PER_ENTITY_BEHAVIOR_FINAL_AT_TIME\x10\x03\x42\xfb\x01\n\x1b\x63om.kaskada.kaskada.v1alphaB\x0b\x43ommonProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')

_FILETYPE = DESCRIPTOR.enum_types_by_name['FileType']
FileType = enum_type_wrapper.EnumTypeWrapper(_FILETYPE)
_PERENTITYBEHAVIOR = DESCRIPTOR.enum_types_by_name['PerEntityBehavior']
PerEntityBehavior = enum_type_wrapper.EnumTypeWrapper(_PERENTITYBEHAVIOR)
FILE_TYPE_UNSPECIFIED = 0
FILE_TYPE_PARQUET = 1
FILE_TYPE_CSV = 2
PER_ENTITY_BEHAVIOR_UNSPECIFIED = 0
PER_ENTITY_BEHAVIOR_ALL = 1
PER_ENTITY_BEHAVIOR_FINAL = 2
PER_ENTITY_BEHAVIOR_FINAL_AT_TIME = 3


_FILEPATH = DESCRIPTOR.message_types_by_name['FilePath']
_FILEINPUT = DESCRIPTOR.message_types_by_name['FileInput']
_FILERESULTS = DESCRIPTOR.message_types_by_name['FileResults']
_ASFILES = DESCRIPTOR.message_types_by_name['AsFiles']
_TABLECONFIG = DESCRIPTOR.message_types_by_name['TableConfig']
_TABLEMETADATA = DESCRIPTOR.message_types_by_name['TableMetadata']
_PREPAREDFILE = DESCRIPTOR.message_types_by_name['PreparedFile']
_PREPAREDFILEMETADATA = DESCRIPTOR.message_types_by_name['PreparedFileMetadata']
_SLICEPLAN = DESCRIPTOR.message_types_by_name['SlicePlan']
_SLICEPLAN_PERCENTSLICE = _SLICEPLAN.nested_types_by_name['PercentSlice']
_SLICEPLAN_ENTITYKEYSSLICE = _SLICEPLAN.nested_types_by_name['EntityKeysSlice']
_UUID = DESCRIPTOR.message_types_by_name['Uuid']
_SLICEREQUEST = DESCRIPTOR.message_types_by_name['SliceRequest']
_SLICEREQUEST_PERCENTSLICE = _SLICEREQUEST.nested_types_by_name['PercentSlice']
_SLICEREQUEST_ENTITYKEYSSLICE = _SLICEREQUEST.nested_types_by_name['EntityKeysSlice']
_ANALYSIS = DESCRIPTOR.message_types_by_name['Analysis']
_REQUESTDETAILS = DESCRIPTOR.message_types_by_name['RequestDetails']
FilePath = _reflection.GeneratedProtocolMessageType('FilePath', (_message.Message,), {
  'DESCRIPTOR' : _FILEPATH,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.FilePath)
  })
_sym_db.RegisterMessage(FilePath)

FileInput = _reflection.GeneratedProtocolMessageType('FileInput', (_message.Message,), {
  'DESCRIPTOR' : _FILEINPUT,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.FileInput)
  })
_sym_db.RegisterMessage(FileInput)

FileResults = _reflection.GeneratedProtocolMessageType('FileResults', (_message.Message,), {
  'DESCRIPTOR' : _FILERESULTS,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.FileResults)
  })
_sym_db.RegisterMessage(FileResults)

AsFiles = _reflection.GeneratedProtocolMessageType('AsFiles', (_message.Message,), {
  'DESCRIPTOR' : _ASFILES,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.AsFiles)
  })
_sym_db.RegisterMessage(AsFiles)

TableConfig = _reflection.GeneratedProtocolMessageType('TableConfig', (_message.Message,), {
  'DESCRIPTOR' : _TABLECONFIG,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.TableConfig)
  })
_sym_db.RegisterMessage(TableConfig)

TableMetadata = _reflection.GeneratedProtocolMessageType('TableMetadata', (_message.Message,), {
  'DESCRIPTOR' : _TABLEMETADATA,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.TableMetadata)
  })
_sym_db.RegisterMessage(TableMetadata)

PreparedFile = _reflection.GeneratedProtocolMessageType('PreparedFile', (_message.Message,), {
  'DESCRIPTOR' : _PREPAREDFILE,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.PreparedFile)
  })
_sym_db.RegisterMessage(PreparedFile)

PreparedFileMetadata = _reflection.GeneratedProtocolMessageType('PreparedFileMetadata', (_message.Message,), {
  'DESCRIPTOR' : _PREPAREDFILEMETADATA,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.PreparedFileMetadata)
  })
_sym_db.RegisterMessage(PreparedFileMetadata)

SlicePlan = _reflection.GeneratedProtocolMessageType('SlicePlan', (_message.Message,), {

  'PercentSlice' : _reflection.GeneratedProtocolMessageType('PercentSlice', (_message.Message,), {
    'DESCRIPTOR' : _SLICEPLAN_PERCENTSLICE,
    '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.SlicePlan.PercentSlice)
    })
  ,

  'EntityKeysSlice' : _reflection.GeneratedProtocolMessageType('EntityKeysSlice', (_message.Message,), {
    'DESCRIPTOR' : _SLICEPLAN_ENTITYKEYSSLICE,
    '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.SlicePlan.EntityKeysSlice)
    })
  ,
  'DESCRIPTOR' : _SLICEPLAN,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.SlicePlan)
  })
_sym_db.RegisterMessage(SlicePlan)
_sym_db.RegisterMessage(SlicePlan.PercentSlice)
_sym_db.RegisterMessage(SlicePlan.EntityKeysSlice)

Uuid = _reflection.GeneratedProtocolMessageType('Uuid', (_message.Message,), {
  'DESCRIPTOR' : _UUID,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Uuid)
  })
_sym_db.RegisterMessage(Uuid)

SliceRequest = _reflection.GeneratedProtocolMessageType('SliceRequest', (_message.Message,), {

  'PercentSlice' : _reflection.GeneratedProtocolMessageType('PercentSlice', (_message.Message,), {
    'DESCRIPTOR' : _SLICEREQUEST_PERCENTSLICE,
    '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.SliceRequest.PercentSlice)
    })
  ,

  'EntityKeysSlice' : _reflection.GeneratedProtocolMessageType('EntityKeysSlice', (_message.Message,), {
    'DESCRIPTOR' : _SLICEREQUEST_ENTITYKEYSSLICE,
    '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.SliceRequest.EntityKeysSlice)
    })
  ,
  'DESCRIPTOR' : _SLICEREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.SliceRequest)
  })
_sym_db.RegisterMessage(SliceRequest)
_sym_db.RegisterMessage(SliceRequest.PercentSlice)
_sym_db.RegisterMessage(SliceRequest.EntityKeysSlice)

Analysis = _reflection.GeneratedProtocolMessageType('Analysis', (_message.Message,), {
  'DESCRIPTOR' : _ANALYSIS,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Analysis)
  })
_sym_db.RegisterMessage(Analysis)

RequestDetails = _reflection.GeneratedProtocolMessageType('RequestDetails', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDETAILS,
  '__module__' : 'kaskada.kaskada.v1alpha.common_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.RequestDetails)
  })
_sym_db.RegisterMessage(RequestDetails)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\013CommonProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _FILETYPE._serialized_start=2223
  _FILETYPE._serialized_end=2302
  _PERENTITYBEHAVIOR._serialized_start=2305
  _PERENTITYBEHAVIOR._serialized_end=2460
  _FILEPATH._serialized_start=216
  _FILEPATH._serialized_end=329
  _FILEINPUT._serialized_start=331
  _FILEINPUT._serialized_end=424
  _FILERESULTS._serialized_start=426
  _FILERESULTS._serialized_end=525
  _ASFILES._serialized_start=527
  _ASFILES._serialized_end=600
  _TABLECONFIG._serialized_start=603
  _TABLECONFIG._serialized_end=848
  _TABLEMETADATA._serialized_start=850
  _TABLEMETADATA._serialized_end=953
  _PREPAREDFILE._serialized_start=956
  _PREPAREDFILE._serialized_end=1186
  _PREPAREDFILEMETADATA._serialized_start=1189
  _PREPAREDFILEMETADATA._serialized_end=1325
  _SLICEPLAN._serialized_start=1328
  _SLICEPLAN._serialized_end=1637
  _SLICEPLAN_PERCENTSLICE._serialized_start=1536
  _SLICEPLAN_PERCENTSLICE._serialized_end=1576
  _SLICEPLAN_ENTITYKEYSSLICE._serialized_start=1578
  _SLICEPLAN_ENTITYKEYSSLICE._serialized_end=1628
  _UUID._serialized_start=1639
  _UUID._serialized_end=1683
  _SLICEREQUEST._serialized_start=1686
  _SLICEREQUEST._serialized_end=1973
  _SLICEREQUEST_PERCENTSLICE._serialized_start=1536
  _SLICEREQUEST_PERCENTSLICE._serialized_end=1576
  _SLICEREQUEST_ENTITYKEYSSLICE._serialized_start=1914
  _SLICEREQUEST_ENTITYKEYSSLICE._serialized_end=1964
  _ANALYSIS._serialized_start=1976
  _ANALYSIS._serialized_end=2172
  _REQUESTDETAILS._serialized_start=2174
  _REQUESTDETAILS._serialized_end=2221
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from kaskada.kaskada.v1alpha import materialization_service_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2


class MaterializationServiceStub(object):
    """A service for managing Materializations.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListMaterializations = channel.unary_unary(
                '/kaskada.kaskada.v1alpha.MaterializationService/ListMaterializations',
                request_serializer=kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.ListMaterializationsRequest.SerializeToString,
                response_deserializer=kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.ListMaterializationsResponse.FromString,
                )
        self.GetMaterialization = channel.unary_unary(
                '/kaskada.kaskada.v1alpha.MaterializationService/GetMaterialization',
                request_serializer=kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.GetMaterializationRequest.SerializeToString,
                response_deserializer=kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.GetMaterializationResponse.FromString,
                )
        self.CreateMaterialization = channel.unary_unary(
                '/kaskada.kaskada.v1alpha.MaterializationService/CreateMaterialization',
                request_serializer=kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.CreateMaterializationRequest.SerializeToString,
                response_deserializer=kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.CreateMaterializationResponse.FromString,
                )
        self.DeleteMaterialization = channel.unary_unary(
                '/kaskada.kaskada.v1alpha.MaterializationService/DeleteMaterialization',
                request_serializer=kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.DeleteMaterializationRequest.SerializeToString,
                response_deserializer=kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.DeleteMaterializationResponse.FromString,
                )


class MaterializationServiceServicer(object):
    """A service for managing Materializations.
    """

    def ListMaterializations(self, request, context):
        """Lists materializations.

        The response includes all Materializations defined for the Kaskada
        account. If a search string is provided, only Materializations
        matching the search string are returned.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMaterialization(self, request, context):
        """Gets a materialization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMaterialization(self, request, context):
        """Creates a materialization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMaterialization(self, request, context):
        """Deletes a materialization and any events loaded into it.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MaterializationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListMaterializations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMaterializations,
                    request_deserializer=kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.ListMaterializationsRequest.FromString,
                    response_serializer=kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.ListMaterializationsResponse.SerializeToString,
            ),
            'GetMaterialization': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMaterialization,
                    request_deserializer=kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.GetMaterializationRequest.FromString,
                    response_serializer=kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.GetMaterializationResponse.SerializeToString,
            ),
            'CreateMaterialization': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMaterialization,
                    request_deserializer=kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.CreateMaterializationRequest.FromString,
                    response_serializer=kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.CreateMaterializationResponse.SerializeToString,
            ),
            'DeleteMaterialization': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteMaterialization,
                    request_deserializer=kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.DeleteMaterializationRequest.FromString,
                    response_serializer=kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.DeleteMaterializationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kaskada.kaskada.v1alpha.MaterializationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MaterializationService(object):
    """A service for managing Materializations.
    """

    @staticmethod
    def ListMaterializations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kaskada.kaskada.v1alpha.MaterializationService/ListMaterializations',
            kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.ListMaterializationsRequest.SerializeToString,
            kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.ListMaterializationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMaterialization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kaskada.kaskada.v1alpha.MaterializationService/GetMaterialization',
            kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.GetMaterializationRequest.SerializeToString,
            kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.GetMaterializationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateMaterialization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kaskada.kaskada.v1alpha.MaterializationService/CreateMaterialization',
            kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.CreateMaterializationRequest.SerializeToString,
            kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.CreateMaterializationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteMaterialization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kaskada.kaskada.v1alpha.MaterializationService/DeleteMaterialization',
            kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.DeleteMaterializationRequest.SerializeToString,
            kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2.DeleteMaterializationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import logging
import sys
import traceback
from typing import List, Optional, Tuple

import certifi
import grpc
import IPython

import kaskada.formatters
import kaskada.kaskada.v1alpha.materialization_service_pb2_grpc as mat_grpc
import kaskada.kaskada.v1alpha.query_service_pb2_grpc as query_grpc
import kaskada.kaskada.v1alpha.table_service_pb2_grpc as table_grpc
import kaskada.kaskada.v1alpha.view_service_pb2_grpc as view_grpc
from kaskada.slice_filters import SliceFilter

logging.basicConfig(stream=sys.stdout, level=logging.INFO)
logger = logging.getLogger(__name__)

# Module global client configured at initialization time. By default, all
# API calls utilize the global client config
KASKADA_DEFAULT_CLIENT = None
# The slicing parameter passed to query by default. By default, this is None.
KASKADA_DEFAULT_SLICE = None
# The default API server is localhost.
KASKADA_DEFAULT_ENDPOINT = "localhost:50051"
# The default local API server does not use a secure connection
KASKADA_IS_SECURE = False


def showtraceback(_self, *_args, **_kwargs):
    """Upates the IPython interactive shell to show tracebook"""
    traceback_lines = traceback.format_exception(*sys.exc_info())
    message = traceback_lines[-1]
    sys.stderr.write(message)


# fmt: off
IPython.core.interactiveshell.InteractiveShell.showtraceback = showtraceback # type:ignore
# fmt: on


def init(
    client_id: Optional[str] = None,
    endpoint: Optional[str] = KASKADA_DEFAULT_ENDPOINT,
    is_secure: bool = KASKADA_IS_SECURE,
):
    """
    Initializes the Kaskada library with a client. Creating a client will update the default module default client.

    Args:
        client_id (str, optional): Kaskada Client ID.
        endpoint (str, optional): API Endpoint. Defaults to KASKADA_DEFAULT_ENDPOINT/localhost:50051.
        is_secure (bool): Use SSL connection. Defaults to False.
    Returns:
        Client: Kaskada Client
    """
    kaskada.formatters.try_init()
    logger.debug(
        f"Client initialized with client_id: {client_id}, endpoint: {endpoint}, is_secure: {is_secure}"
    )
    global KASKADA_DEFAULT_CLIENT
    KASKADA_DEFAULT_CLIENT = Client(
        client_id=client_id,
        endpoint=endpoint,
        is_secure=is_secure,
    )


def set_default_slice(slice: SliceFilter):
    """
    Sets the default slice used in every query

    Args:
        slice (SliceFilter): SliceFilter to set the default
    """
    logger.debug(f"Default slice set to type {type(slice)}")

    global KASKADA_DEFAULT_SLICE
    KASKADA_DEFAULT_SLICE = slice


class Client(object):
    def __init__(
        self,
        client_id: Optional[str] = None,
        endpoint: Optional[str] = None,
        is_secure: bool = True,
    ):
        if is_secure:
            with open(certifi.where(), "rb") as f:
                trusted_certs = f.read()
            credentials = grpc.ssl_channel_credentials(root_certificates=trusted_certs)
            channel = grpc.secure_channel(endpoint, credentials)
        else:
            channel = grpc.insecure_channel(endpoint)
        self.table_stub = table_grpc.TableServiceStub(channel)
        self.view_stub = view_grpc.ViewServiceStub(channel)
        self.query_stub = query_grpc.QueryServiceStub(channel)
        self.materialization_stub = mat_grpc.MaterializationServiceStub(channel)
        self.client_id = client_id

    def get_metadata(self) -> List[Tuple[str, str]]:
        """
        Fetches the metadata for the current client. Renews token if necessary.

        Raises:
            Exception: invalid token

        Returns:
            List[Tuple[str, str]]: Client metadata
        """
        metadata: List[Tuple[str, str]] = []
        if self.client_id is not None:
            metadata.append(("client-id", self.client_id))
        return metadata


def validate_client(client: Client):
    """Valides the client by checking the service stubs

    Args:
        client (Client): The client to validate

    Raises:
        ValueError: View service stub was not initialized properly.
        ValueError: Table service stubs was not initialized properly.
        ValueError: Query service stubs was not initialized properly.
        ValueError: Materialization service stubs was not initialized properly.
    """
    if client.view_stub is None:
        raise ValueError(
            "Invalid client provided. View service stub was not initialized properly."
        )
    if client.table_stub is None:
        raise ValueError(
            "Invalid client provided. Table service stubs was not initialized properly."
        )
    if client.query_stub is None:
        raise ValueError(
            "Invalid client provided. Query service stubs was not initialized properly."
        )
    if client.materialization_stub is None:
        raise ValueError(
            "Invalid client provided. Materialization service stubs was not initialized properly."
        )


def get_client(client: Optional[Client] = None) -> Client:
    """Gets and validates the current client. If no client is provided, the global client is returned.

    Args:
        client (Optional[Client], optional): An optional client to verify Defaults to the global client.

    Raises:
        ValueError: No client is initialized or client is improperly initialized

    Returns:
        Client: The provided client argument or the global client.
    """
    if client is None and KASKADA_DEFAULT_CLIENT is None:
        raise ValueError("Client must be provided")
    elif client is None:
        client = KASKADA_DEFAULT_CLIENT

    if client is None:
        raise ValueError("Client must be provided")
    validate_client(client)
    return client



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src', 'fenlmagic': 'src/fenlmagic', 'validate': 'vendor/validate'}

packages = \
['fenlmagic',
 'kaskada',
 'kaskada.api',
 'kaskada.kaskada.v1alpha',
 'kaskada.kaskada.v2alpha',
 'validate']

package_data = \
{'': ['*']}

install_requires = \
['certifi>=2022.12.7,<2023.0.0',
 'domonic>=0.9.11,<0.10.0',
 'googleapis-common-protos>=1.58.0,<2.0.0',
 'grpcio-status>=1.51.1,<2.0.0',
 'grpcio>=1.51.1,<2.0.0',
 'html5lib>=1.1,<2.0',
 'ipython==7.34.0',
 'pandas>=1.3,<1.4',
 'pyarrow>=10.0.1,<11.0.0',
 'pygithub>=1.57,<2.0',
 'requests>=2.28.2,<3.0.0',
 'tqdm>=4.64.1,<5.0.0']

setup_kwargs = {
    'name': 'kaskada',
    'version': '0.1.1a5',
    'description': 'A client library for the Kaskada time travel machine learning service',
    'long_description': '# Kaskada SDK\n\n## Developer Instructions\nThe package uses Poetry to develop and build.\n\n1. Install Pyenv [Pyenv Documentation](https://github.com/pyenv/pyenv)\n1. Install Python 3.9.16: `$ pyenv install 3.9.16`\n1. Install Poetry [Poetry Documentation](https://python-poetry.org/docs/)\n1. Install dependences: `$ poetry install`\n\n### Run tasks\nThe package uses [`poethepoet`](https://github.com/nat-n/poethepoet) for running tasks\n\n#### Test Task\nTo run tests: `$ poetry run poe test` \n\n#### Check Style Task\nTo check the style: `$ poetry run poe style`\n\n#### Format Task\nTo auto-format (isort + black): `$ poetry run poe format`\n\n#### Check Static Type Task\nTo perform static type analysis (mypy): `$ poetry run poe types`\n\n#### Lint Task\nTo run the linter (pylint): `$ poetry run poe lint`\n',
    'author': 'Kaskada',
    'author_email': 'support@kaskada.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7.2,<4.0.0',
}


setup(**setup_kwargs)



import logging
import os
import sys
import time
import uuid
from abc import ABC
from pathlib import Path
from subprocess import Popen
from typing import Optional

import kaskada.client
from kaskada.api import api_utils, release

logging.basicConfig(stream=sys.stdout, level=logging.INFO)
logger = logging.getLogger(__name__)


class Session:
    def __init__(
        self,
        endpoint: str,
        is_secure: bool,
        name: str,
        client_id: Optional[str] = None,
        api_process: Optional[Popen] = None,
        compute_process: Optional[Popen] = None,
    ) -> None:
        self._endpoint = endpoint
        self._is_secure = is_secure
        self._name = name
        self._client_id = client_id
        self._client = self.connect()
        self._api_process = api_process
        self._compute_process = compute_process

    def __del__(self):
        if self._api_process is not None:
            logger.info("Stopping Kaskada Manager server")
            self._api_process.kill()

        if self._compute_process is not None:
            logger.info("Stopping Kaskada Engine server")
            self._compute_process.kill()

    def connect(self):
        attempt = 0
        is_valid_session = False
        while attempt < 3 and not is_valid_session:
            logger.debug(f"Attempting (try #{attempt}) to connect to {self._endpoint}")
            if api_utils.check_socket(self._endpoint):
                logger.info(f"Successfully connected to session.")
                is_valid_session = True
            attempt += 1
            # Sleep with exponential backoff
            time.sleep(1.5**attempt)
        if is_valid_session == False:
            raise ConnectionError(
                "unable to connect to API or Compute engine after {} attempts".format(
                    attempt
                )
            )
        return kaskada.client.init(self._client_id, self._endpoint, self._is_secure)


class Builder(ABC):
    def __init__(
        self,
        endpoint: Optional[str] = None,
        is_secure: Optional[bool] = None,
        name: str = str(uuid.uuid4()),
        client_id: Optional[str] = None,
    ) -> None:
        super().__init__()
        self._endpoint: Optional[str] = endpoint
        self._is_secure: Optional[bool] = is_secure
        self._name: str = name
        self._client_id: Optional[str] = client_id

    def endpoint(self, endpoint: str, is_secure: bool):
        self._endpoint = endpoint
        self._is_secure = is_secure
        return self

    def name(self, name: str):
        self._name = name
        return self

    def client_id(self, client_id: str):
        self._client_id = client_id
        return self


KASKADA_ENDPOINT_DEFAULT = "localhost:50051"
KASKADA_IS_SECURE_DEFAULT = False


class LocalBuilder(Builder):
    KASKADA_PATH_ENV = "KASKADA_PATH"
    KASKADA_PATH_DEFAULT = "~/.cache/kaskada"
    KASKADA_LOG_PATH_DEFAULT = "logs"
    KASKADA_LOG_PATH_ENV = "KASKADA_LOG_PATH"
    KASKADA_BIN_PATH_DEFAULT = "bin"
    KASKADA_BIN_PATH_ENV = "KASKADA_BIN_PATH"

    KASKADA_MANAGER_BIN_NAME_DEFAULT = "kaskada-manager"
    KASKADA_ENGINE_BIN_NAME_DEFAULT = "kaskada-engine"

    def __init__(
        self,
        endpoint: str = KASKADA_ENDPOINT_DEFAULT,
        is_secure: bool = KASKADA_IS_SECURE_DEFAULT,
    ) -> None:
        super().__init__()
        self._path: str = os.getenv(
            LocalBuilder.KASKADA_PATH_ENV, LocalBuilder.KASKADA_PATH_DEFAULT
        )
        self._bin_path: str = os.getenv(
            LocalBuilder.KASKADA_BIN_PATH_ENV, LocalBuilder.KASKADA_BIN_PATH_DEFAULT
        )
        self._log_path: str = os.getenv(
            LocalBuilder.KASKADA_LOG_PATH_ENV, LocalBuilder.KASKADA_LOG_PATH_DEFAULT
        )
        self.endpoint(endpoint, is_secure)
        self._download = True

    def path(self, path: str):
        self._path = path
        return self

    def log_path(self, path: str):
        self._log_path = path
        return self

    def bin_path(self, path: str):
        self._bin_path = path
        return self

    def download(self, download: bool):
        self._download = download
        return self

    def __get_log_path(self, file_name: str) -> Path:
        if self._path is None:
            raise ValueError("no path provided and KASKADA_PATH was not set")
        if self._log_path is None:
            raise ValueError("no log path provided and KASKADA_LOG_PATH was not set")
        log_path = Path(
            "{}/{}/{}".format(self._path, self._log_path, self._name)
        ).expanduser()
        log_path.mkdir(parents=True, exist_ok=True)
        return log_path / file_name

    def __get_binary_path(self) -> Path:
        if self._path is None:
            raise ValueError("no path provided and KASKADA_PATH was not set")
        if self._bin_path is None:
            raise ValueError("no bin path provided and KASKADA_BIN_PATH was not set")
        bin_path = Path("{}/{}".format(self._path, self._bin_path)).expanduser()
        bin_path.mkdir(parents=True, exist_ok=True)
        return bin_path

    def __start(self):
        api_binary_path = (
            self.__get_binary_path() / self.KASKADA_MANAGER_BIN_NAME_DEFAULT
        )
        api_log_path = self.__get_log_path("api_logs.txt")
        compute_binary_path = (
            self.__get_binary_path() / self.KASKADA_ENGINE_BIN_NAME_DEFAULT
        )
        compute_log_path = self.__get_log_path("compute_logs.txt")
        compute_params = "serve"

        # TODO: Verify the logging output (stdout/stderr)
        api_cmd = "{} > {} 2>&1".format(api_binary_path, api_log_path)
        logger.debug(f"Manager start command: {api_cmd}")
        compute_cmd = "{} {} > {} 2>&1".format(
            compute_binary_path, compute_params, compute_log_path
        )
        logger.debug(f"Compute start command: {compute_cmd}")
        logger.info("Initializing manager process")
        api_process = api_utils.run_subprocess(api_cmd)
        logger.info("Initializing compute process")
        compute_process = api_utils.run_subprocess(compute_cmd)
        return (api_process, compute_process)

    def __download_latest_release(self):
        """Downloads the latest release version to the binary path."""
        client = release.ReleaseClient()
        download_path = self.__get_binary_path()
        download_path.mkdir(parents=True, exist_ok=True)
        local_release = client.download_latest_release(
            download_path,
            self.KASKADA_MANAGER_BIN_NAME_DEFAULT,
            self.KASKADA_ENGINE_BIN_NAME_DEFAULT,
        )
        logger.debug(f"Download Path: {local_release._download_path}")
        logger.debug(f"Manager Path: {local_release._manager_path}")
        logger.debug(f"Engine Path: {local_release._manager_path}")
        # Update the binary path to the path downloaded and saved to by the latest release downloader.
        self.bin_path(
            local_release._download_path.absolute().relative_to(
                Path(self._path).expanduser().absolute()
            )
        )
        os.chmod(local_release._manager_path, 0o755)
        os.chmod(local_release._engine_path, 0o755)

    def build(self) -> Session:
        """Builds the local session. Starts by downloading the latest release and starting the local binaries.

        Returns:
            Session: The local session object
        """
        if self._download:
            self.__download_latest_release()
        api_process, compute_process = self.__start()
        if self._endpoint is None:
            raise ValueError("endpoint was not set")
        if self._is_secure is None:
            raise ValueError("is_secure was not set")

        return Session(
            self._endpoint,
            self._is_secure,
            self._name,
            client_id=self._client_id,
            api_process=api_process,
            compute_process=compute_process,
        )


class RemoteBuilder(Builder):
    def __init__(self) -> None:
        super().__init__()

    def build(self):
        return Session(
            self._endpoint, self._is_secure, self._name, client_id=self._client_id
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/data_token_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaskada.kaskada.v1alpha import common_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0kaskada/kaskada/v1alpha/data_token_service.proto\x12\x17kaskada.kaskada.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$kaskada/kaskada/v1alpha/common.proto\"\x9b\x02\n\tDataToken\x12\'\n\rdata_token_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x61taTokenId\x12\x61\n\x0etable_versions\x18\x02 \x03(\x0b\x32\x35.kaskada.kaskada.v1alpha.DataToken.TableVersionsEntryB\x03\xe0\x41\x03R\rtableVersions\x12@\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x1a@\n\x12TableVersionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x03R\x05value:\x02\x38\x01\"9\n\x13GetDataTokenRequest\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\"\xab\x01\n\x14GetDataTokenResponse\x12\x41\n\ndata_token\x18\x01 \x01(\x0b\x32\".kaskada.kaskada.v1alpha.DataTokenR\tdataToken\x12P\n\x0frequest_details\x18\x02 \x01(\x0b\x32\'.kaskada.kaskada.v1alpha.RequestDetailsR\x0erequestDetails2\xb0\x01\n\x10\x44\x61taTokenService\x12\x9b\x01\n\x0cGetDataToken\x12,.kaskada.kaskada.v1alpha.GetDataTokenRequest\x1a-.kaskada.kaskada.v1alpha.GetDataTokenResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1alpha/data_tokens/{data_token_id=*}B\x85\x02\n\x1b\x63om.kaskada.kaskada.v1alphaB\x15\x44\x61taTokenServiceProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')



_DATATOKEN = DESCRIPTOR.message_types_by_name['DataToken']
_DATATOKEN_TABLEVERSIONSENTRY = _DATATOKEN.nested_types_by_name['TableVersionsEntry']
_GETDATATOKENREQUEST = DESCRIPTOR.message_types_by_name['GetDataTokenRequest']
_GETDATATOKENRESPONSE = DESCRIPTOR.message_types_by_name['GetDataTokenResponse']
DataToken = _reflection.GeneratedProtocolMessageType('DataToken', (_message.Message,), {

  'TableVersionsEntry' : _reflection.GeneratedProtocolMessageType('TableVersionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATATOKEN_TABLEVERSIONSENTRY,
    '__module__' : 'kaskada.kaskada.v1alpha.data_token_service_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.DataToken.TableVersionsEntry)
    })
  ,
  'DESCRIPTOR' : _DATATOKEN,
  '__module__' : 'kaskada.kaskada.v1alpha.data_token_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.DataToken)
  })
_sym_db.RegisterMessage(DataToken)
_sym_db.RegisterMessage(DataToken.TableVersionsEntry)

GetDataTokenRequest = _reflection.GeneratedProtocolMessageType('GetDataTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATATOKENREQUEST,
  '__module__' : 'kaskada.kaskada.v1alpha.data_token_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetDataTokenRequest)
  })
_sym_db.RegisterMessage(GetDataTokenRequest)

GetDataTokenResponse = _reflection.GeneratedProtocolMessageType('GetDataTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATATOKENRESPONSE,
  '__module__' : 'kaskada.kaskada.v1alpha.data_token_service_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.GetDataTokenResponse)
  })
_sym_db.RegisterMessage(GetDataTokenResponse)

_DATATOKENSERVICE = DESCRIPTOR.services_by_name['DataTokenService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\025DataTokenServiceProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _DATATOKEN_TABLEVERSIONSENTRY._options = None
  _DATATOKEN_TABLEVERSIONSENTRY._serialized_options = b'8\001'
  _DATATOKEN.fields_by_name['data_token_id']._options = None
  _DATATOKEN.fields_by_name['data_token_id']._serialized_options = b'\340A\003'
  _DATATOKEN.fields_by_name['table_versions']._options = None
  _DATATOKEN.fields_by_name['table_versions']._serialized_options = b'\340A\003'
  _DATATOKEN.fields_by_name['create_time']._options = None
  _DATATOKEN.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _DATATOKENSERVICE.methods_by_name['GetDataToken']._options = None
  _DATATOKENSERVICE.methods_by_name['GetDataToken']._serialized_options = b'\202\323\344\223\002(\022&/v1alpha/data_tokens/{data_token_id=*}'
  _DATATOKEN._serialized_start=212
  _DATATOKEN._serialized_end=495
  _DATATOKEN_TABLEVERSIONSENTRY._serialized_start=431
  _DATATOKEN_TABLEVERSIONSENTRY._serialized_end=495
  _GETDATATOKENREQUEST._serialized_start=497
  _GETDATATOKENREQUEST._serialized_end=554
  _GETDATATOKENRESPONSE._serialized_start=557
  _GETDATATOKENRESPONSE._serialized_end=728
  _DATATOKENSERVICE._serialized_start=731
  _DATATOKENSERVICE._serialized_end=907
# @@protoc_insertion_point(module_scope)
